@@ -234,7 +234,7 @@ def trace_monotonic(
 
 
 def trace(
-    func: Callable = None,
+    function: Callable = None,
     *,
     do_trace: bool = True,
     function_name: str = '',
@@ -246,7 +246,7 @@ def trace(
         stack_analyzer=stack_analyzer,
     )
 
-    if func:
-        return wrapper(func)
+    if function:
+        return wrapper(function)
 
     return wrapper
